"""
kutilities

Provides template utility functions as well as 
generate base template files for use with webdevelopment frameworks
"""

__version__ = "0.1.0"
__author__ = 'Chase Kaleikilo'
__credits__ = 'Kaleiko'

def health_check():
    print("hello world!")



from setuptools import setup

setup(
    name='kutilities',
    version='0.1.0',
    description='Provides template utility functions as well as generate'
                'base teßßmplate files used within web development frameworks',
    url='https://github.com/Kaleiko/kutilities',
    author='Chase Kaleikilo',
    author_email='code@kaleiko.net',
    license='MIT License',
    packages=['kutilities'],
    zip_safe=False,
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
        'License :: Freeware',  
        'Operating System :: POSIX :: Linux',    
        'Programming Language :: Python :: 3.10',
    ],
)